==> sdk-web-components-11.0.1.tgz: package/dist-vite/collection/components/bp-sdk-vehicle-makes/bp-sdk-vehicle-makes.spec.js <==
import { newSpecPage } from "@stencil/core/testing";
import { BpSdkVehicleMakes } from "./bp-sdk-vehicle-makes";
describe('bp-sdk-vehicle-makes', () => {
    it('renders', async () => {
        const page = await newSpecPage({
            html: '<bp-sdk-vehicle-makes></bp-sdk-vehicle-makes>',
            components: [BpSdkVehicleMakes],
        });
        await page.waitForChanges();
        const element = page.root.querySelector('bp-sdk-dynamic-input');
        expect(element).toBeTruthy();
    });
    it('renders external component if defined', async () => {
        const whenDefinedMock = jest.spyOn(customElements, 'whenDefined').mockResolvedValueOnce({});
        const page = await newSpecPage({
            html: '<bp-sdk-vehicle-makes></bp-sdk-vehicle-makes>',
            components: [BpSdkVehicleMakes],
        });
        await page.waitForChanges();
        const element = page.root.querySelector('bp-sdk-dynamic-input');
        expect(element).toBeFalsy();
        whenDefinedMock.mockRestore();
    });
    describe('onIsVehicleTrailerChange', () => {
        it('case: true', async () => {
            const page = await newSpecPage({
                html: '<bp-sdk-vehicle-makes></bp-sdk-vehicle-makes>',
                components: [BpSdkVehicleMakes],
            });
            const instance = page.rootInstance;
            instance.fieldType = '';
            instance.inputComponentType = '';
            instance.onIsVehicleTrailerChange(true);
            expect(instance.fieldType).toEqual('vehicle');
            expect(instance.fieldType).toEqual('vehicle');
        });
        it('case: false', async () => {
            const page = await newSpecPage({
                html: '<bp-sdk-vehicle-makes></bp-sdk-vehicle-makes>',
                components: [BpSdkVehicleMakes],
            });
            const instance = page.rootInstance;
            instance.fieldType = '';
            instance.inputComponentType = '';
            instance.onIsVehicleTrailerChange(false);
            expect(instance.fieldType).toEqual('dropdown');
            expect(instance.fieldType).toEqual('dropdown');
        });
    });
});

==> sdk-web-components-12.1.0.tgz: package/dist-vite/collection/components/bp-sdk-vehicle-makes/bp-sdk-vehicle-makes.spec.js <==
import { newSpecPage } from "@stencil/core/testing";
import { BpSdkVehicleMakes } from "./bp-sdk-vehicle-makes";
describe('bp-sdk-vehicle-makes', () => {
    it('renders', async () => {
        const page = await newSpecPage({
            html: '<bp-sdk-vehicle-makes></bp-sdk-vehicle-makes>',
            components: [BpSdkVehicleMakes],
        });
        await page.waitForChanges();
        const element = page.root.querySelector('bp-sdk-dynamic-input');
        expect(element).toBeTruthy();
    });
    it('renders external component if defined', async () => {
        const whenDefinedMock = jest
            .spyOn(customElements, 'whenDefined')
            .mockResolvedValueOnce({});
        const page = await newSpecPage({
            html: '<bp-sdk-vehicle-makes></bp-sdk-vehicle-makes>',
            components: [BpSdkVehicleMakes],
        });
        await page.waitForChanges();
        const element = page.root.querySelector('bp-sdk-dynamic-input');
        expect(element).toBeFalsy();
        whenDefinedMock.mockRestore();
    });
    describe('onIsVehicleTrailerChange', () => {
        it('case: true', async () => {
            const page = await newSpecPage({
                html: '<bp-sdk-vehicle-makes></bp-sdk-vehicle-makes>',
                components: [BpSdkVehicleMakes],
            });
            const instance = page.rootInstance;
            instance.fieldType = '';
            instance.inputComponentType = '';
            instance.onIsVehicleTrailerChange(true);
            expect(instance.fieldType).toEqual('vehicle');
            expect(instance.fieldType).toEqual('vehicle');
        });
        it('case: false', async () => {
            const page = await newSpecPage({
                html: '<bp-sdk-vehicle-makes></bp-sdk-vehicle-makes>',
                components: [BpSdkVehicleMakes],
            });
            const instance = page.rootInstance;
            instance.fieldType = '';
            instance.inputComponentType = '';
            instance.onIsVehicleTrailerChange(false);
            expect(instance.fieldType).toEqual('dropdown');
            expect(instance.fieldType).toEqual('dropdown');
        });
    });
});
